Pass data_size into QuicPacketCreator::CreateStreamFrame instead of calculating it inside the method and no longer special case the 0 length case, except the existing QUIC_BUG.

gfe-relnote: n/a (Code refactor)
PiperOrigin-RevId: 238444568
Change-Id: I66c6ea5046639e91390bb64f88e5ab4e479a1b36
diff --git a/quic/core/quic_packet_creator.h b/quic/core/quic_packet_creator.h
index 7e129e1..76e7726 100644
--- a/quic/core/quic_packet_creator.h
+++ b/quic/core/quic_packet_creator.h
@@ -277,11 +277,10 @@
   friend class test::QuicPacketCreatorPeer;
 
   // Creates a stream frame which fits into the current open packet. If
   // |write_length| is 0 and fin is true, the expected behavior is to consume
   // the fin but return 0.
   void CreateStreamFrame(QuicStreamId id,
-                         size_t write_length,
-                         size_t iov_offset,
+                         size_t data_size,
                          QuicStreamOffset offset,
                          bool fin,
                          QuicFrame* frame);
@@ -277,11 +277,10 @@
 
   // Creates a stream frame which fits into the current open packet. If
-  // |write_length| is 0 and fin is true, the expected behavior is to consume
-  // the fin but return 0.
+  // |data_size| is 0 and fin is true, the expected behavior is to consume
+  // the fin.
   void CreateStreamFrame(QuicStreamId id,